==> wire-runtime-3.1.0-javadoc.jar: wire-schema/com.squareup.wire.schema/-one-of/index.md <==
[wire-schema](../../index.md) / [com.squareup.wire.schema](../index.md) / [OneOf](./index.md)

# OneOf

`class OneOf`

### Properties

| Name | Summary |
|---|---|
| [documentation](documentation.md) | `val documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [fields](fields.md) | `val fields: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Field`](../-field/index.md)`>` |
| [name](name.md) | `val name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |

### Functions

| Name | Summary |
|---|---|
| [link](link.md) | `fun link(linker: `[`Linker`](../-linker/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [linkOptions](link-options.md) | `fun linkOptions(linker: `[`Linker`](../-linker/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [retainAll](retain-all.md) | `fun retainAll(schema: `[`Schema`](../-schema/index.md)`, markSet: `[`MarkSet`](../-mark-set/index.md)`, enclosingType: `[`ProtoType`](../-proto-type/index.md)`): `[`OneOf`](./index.md)`?` |
| [retainLinked](retain-linked.md) | `fun retainLinked(): `[`OneOf`](./index.md)`?` |

### Companion Object Functions

| Name | Summary |
|---|---|
| [fromElements](from-elements.md) | `fun fromElements(packageName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?, elements: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`OneOfElement`](../../com.squareup.wire.schema.internal.parser/-one-of-element/index.md)`>, extension: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): <ERROR CLASS>` |
| [toElements](to-elements.md) | `fun toElements(oneOfs: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`OneOf`](./index.md)`>): <ERROR CLASS>` |

==> wire-runtime-3.7.1-javadoc.jar: wire-schema/com.squareup.wire.schema/-one-of/index.md <==
[wire-schema](../../index.md) / [com.squareup.wire.schema](../index.md) / [OneOf](./index.md)

# OneOf

`data class OneOf`

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | `OneOf(name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, fields: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Field`](../-field/index.md)`>)` |

### Properties

| Name | Summary |
|---|---|
| [documentation](documentation.md) | `val documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [fields](fields.md) | `val fields: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Field`](../-field/index.md)`>` |
| [name](name.md) | `val name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |

### Functions

| Name | Summary |
|---|---|
| [link](link.md) | `fun link(linker: `[`Linker`](../-linker/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [linkOptions](link-options.md) | `fun linkOptions(linker: `[`Linker`](../-linker/index.md)`, syntaxRules: `[`SyntaxRules`](../-syntax-rules/index.md)`, validate: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [retainAll](retain-all.md) | `fun retainAll(schema: `[`Schema`](../-schema/index.md)`, markSet: `[`MarkSet`](../-mark-set/index.md)`, enclosingType: `[`ProtoType`](../-proto-type/index.md)`): `[`OneOf`](./index.md)`?` |
| [retainLinked](retain-linked.md) | `fun retainLinked(): `[`OneOf`](./index.md)`?` |

### Companion Object Functions

| Name | Summary |
|---|---|
| [fromElements](from-elements.md) | `fun fromElements(packageName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?, elements: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`OneOfElement`](../../com.squareup.wire.schema.internal.parser/-one-of-element/index.md)`>, extension: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): <ERROR CLASS>` |
| [toElements](to-elements.md) | `fun toElements(oneOfs: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`OneOf`](./index.md)`>): <ERROR CLASS>` |
